euler_product: Number theory with Euler products
================================================

Description
-----------

This Sage packages enables investigations in number theory using Euler products.

License
-------

GPLv3.0

Upstream Contact
----------------

- https://pypi.org/project/sage-euler-product/
- https://github.com/passagemath/passagemath-pkg-euler-product
